==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkCheckboxMenuItemPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCheckboxMenuItemPeer

// class file dependencies
// @dep_class 618b1a554ed0e446 gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuItemPeer

#include "gnu/java/awt/peer/gtk/GtkMenuItemPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_

// Forward structure declarations
struct _jc_java_awt_CheckboxMenuItem$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$_init$47f1bd785ecf7f11(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_awt_CheckboxMenuItem$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$create$7b5006c0217fdf3e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$postMenuActionEvent$e145740f6e10159e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$setState$b18db6415635747d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$create$7b5006c0217fdf3e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$postMenuActionEvent$e145740f6e10159e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$setState$b18db6415635747d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods {
	void	(*create$7b5006c0217fdf3e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_lang_String$object *);
	void	(*postMenuActionEvent$e145740f6e10159e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *);
	void	(*setState$b18db6415635747d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, jboolean);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkCheckboxMenuItemPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkCheckboxMenuItemPeer

// class file dependencies
// @dep_class 618b1a554ed0e446 gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class a20f5263a96f04a5 gnu_java_awt_peer_gtk_GtkMenuItemPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuItemPeer

#include "gnu/java/awt/peer/gtk/GtkMenuItemPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_

// Forward structure declarations
struct _jc_java_awt_CheckboxMenuItem$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$_init$47f1bd785ecf7f11(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_awt_CheckboxMenuItem$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$create$7b5006c0217fdf3e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$postMenuActionEvent$e145740f6e10159e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method$setState$b18db6415635747d(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$create$7b5006c0217fdf3e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$postMenuActionEvent$e145740f6e10159e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$method_info$setState$b18db6415635747d;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods {
	void	(*create$7b5006c0217fdf3e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*postMenuActionEvent$e145740f6e10159e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *) _JC_JCNI_ATTR;
	void	(*setState$b18db6415635747d)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vmethods	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuItemPeer;
    _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkCheckboxMenuItemPeer_H_ */
